# Generated by Django 4.1.3 on 2023-05-06 15:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('organizations', '0009_issuer_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='organization',
            name='name',
            field=models.CharField(max_length=255, unique=True),
        ),
    ]



# Generated by Django 4.1.3 on 2023-05-08 08:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('organizations', '0010_alter_organization_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='issuer',
            name='did',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='organizations.organizationdid'),
        ),
    ]
